@@ -39,7 +39,13 @@ from shippinglabel.classifiers import validate_classifiers
 # this package
 from whey.builder import AbstractBuilder, SDistBuilder, WheelBuilder
 
-__all__ = ["WheyParser", "backfill_classifiers", "get_default_builders", "get_entry_points"]
+__all__ = [
+		"WheyParser",
+		"backfill_classifiers",
+		"get_default_builders",
+		"get_entry_points",
+		"license_lookup",
+		]
 
 #: Mapping of license short codes to license names used in trove classifiers.
 license_lookup = {
@@ -203,7 +209,7 @@ class WheyParser(AbstractConfigParser):
 						f"Invalid type for 'tool.whey.python-versions[{idx}]': "
 						f"expected {str!r}, {int!r} or {float!r}, got {type(version)!r}"
 						)
-			if str(version) in "12":
+			if str(version)[0] in "12":
 				raise BadConfigError(
 						f"Invalid value for 'tool.whey.python-versions[{idx}]': whey only supports Python 3-only projects."
 						)
@@ -215,10 +221,6 @@ class WheyParser(AbstractConfigParser):
 		Parse the ``python-implementations`` key, giving a list of supported Python implementations. Optional.
 
 		:param config: The unparsed TOML config for the ``[tool.whey]`` table.
-
-		:rtype:
-
-		.. latex:clearpage::
 		"""
 
 		python_implementations = config["python-implementations"]
@@ -237,6 +239,10 @@ class WheyParser(AbstractConfigParser):
 		Ignored if :pep621:`classifiers` is not listed in :pep621:`dynamic`
 
 		:param config: The unparsed TOML config for the ``[tool.whey]`` table.
+
+		:rtype:
+
+		.. latex:clearpage::
 		"""
 
 		parsed_classifiers = set()
